@@ -5,7 +5,7 @@ PyObject *
 BasicMathTwoInputs(PyObject *self, PyObject *args);
 
 PyObject *
-BasicMathTwoInputsFromNumber(PyObject* input1, PyObject* input2, PyObject* output, INT64 funcNumber);
+BasicMathTwoInputsFromNumber(PyObject* input1, PyObject* input2, PyObject* output, int64_t funcNumber);
 
 PyObject *
 Where(PyObject *self, PyObject *args);
