@@ -3,4 +3,4 @@
 PyObject *
 Reduce(PyObject *self, PyObject *args);
 
-PyObject*  ReduceInternal(PyArrayObject *inArr1, INT64 func);
\ No newline at end of file
+PyObject*  ReduceInternal(PyArrayObject *inArr1, int64_t func);
