@@ -31,7 +31,7 @@ void LogWarningLE(HRESULT error) {
 // Checks Windows policy settings if the current process has
 // the privilege enabled.
 // 
-BOOL
+bool
 CheckWindowsPrivilege(const char* pPrivilegeName)
 {
    LUID           luid;
@@ -52,7 +52,7 @@ CheckWindowsPrivilege(const char* pPrivilegeName)
       printf("OpenProcessToken error %u\n", e);
       hResult = HRESULT_FROM_WIN32(e);
       LogWarningLE(hResult);
-      return FALSE;
+      return false;
    }
 
    if (!LookupPrivilegeValue(NULL, pPrivilegeName, &luid))
@@ -63,7 +63,7 @@ CheckWindowsPrivilege(const char* pPrivilegeName)
       printf("LookupPrivilegeValue error %u\n", e);
       hResult = HRESULT_FROM_WIN32(e);
       LogWarningLE(hResult);
-      return FALSE;
+      return false;
    }
 
    privilegeSet.PrivilegeCount = 1;
@@ -81,10 +81,10 @@ CheckWindowsPrivilege(const char* pPrivilegeName)
 
 
 //------------------------------------------------------------------------------------------
-BOOL SetPrivilege(
+bool SetPrivilege(
    HANDLE hToken,          // access token handle
    LPCTSTR lpszPrivilege,  // name of privilege to enable/disable
-   BOOL bEnablePrivilege   // to enable or disable privilege
+   bool bEnablePrivilege   // to enable or disable privilege
 )
 {
    TOKEN_PRIVILEGES tp;
@@ -96,7 +96,7 @@ BOOL SetPrivilege(
       &luid))        // receives LUID of privilege
    {
       printf("LookupPrivilegeValue error: %u\n", GetLastError());
-      return FALSE;
+      return false;
    }
 
    tp.PrivilegeCount = 1;
@@ -110,30 +110,30 @@ BOOL SetPrivilege(
 
    if (!AdjustTokenPrivileges(
       hToken,
-      FALSE,
+      false,
       &tp,
       sizeof(TOKEN_PRIVILEGES),
       (PTOKEN_PRIVILEGES)NULL,
       (PDWORD)NULL))
    {
       printf("AdjustTokenPrivileges error: %u\n", GetLastError());
-      return FALSE;
+      return false;
    }
 
    if (GetLastError() == ERROR_NOT_ALL_ASSIGNED)
 
    {
       printf("The token does not have the specified privilege. \n");
-      return FALSE;
+      return false;
    }
 
-   return TRUE;
+   return true;
 }
 
 
 //------------------------------------------------------------------------------------------
 //
-BOOL
+bool
 CheckWindowsSharedMemoryPrerequisites(const char* pMappingName)
 {
    const char* pPrivilegeName = "SeCreateGlobalPrivilege";
@@ -144,13 +144,13 @@ CheckWindowsSharedMemoryPrerequisites(const char* pMappingName)
 
       // More work to do here
       if (OpenProcessToken(GetCurrentProcess(), TOKEN_ALL_ACCESS, &currentToken)) {
-         BOOL newResult = SetPrivilege(currentToken, pPrivilegeName, TRUE);
+         bool newResult = SetPrivilege(currentToken, pPrivilegeName, true);
          CloseHandle(currentToken);
          return newResult;
       }
-      return FALSE;
+      return false;
    }
-   return TRUE;
+   return true;
 }
 
 //------------------------------------------------------------------------------------------
@@ -401,7 +401,7 @@ UtilSharedMemoryCopy(
    pMappedViewStruct->MapHandle =
       OpenFileMapping(
          FILE_MAP_ALL_ACCESS,
-         FALSE,
+         false,
          pMappingName);
 
    //printf("Result from OpenFileMaApping %s -- %p\n", pMappingName, pMappedViewStruct->MapHandle);
@@ -460,12 +460,12 @@ UtilSharedMemoryEnd(
       return(E_POINTER);
    }
 
-   if (UnmapViewOfFile(pMappedViewStruct->BaseAddress) == FALSE) {
+   if (UnmapViewOfFile(pMappedViewStruct->BaseAddress) == false) {
       hResult = HRESULT_FROM_WIN32(GetLastError());
       return (hResult);
    }
 
-   if (CloseHandle(pMappedViewStruct->MapHandle) == FALSE) {
+   if (CloseHandle(pMappedViewStruct->MapHandle) == false) {
       hResult = HRESULT_FROM_WIN32(GetLastError());
       return (hResult);
    }
@@ -636,12 +636,12 @@ UtilMappedViewReadEnd(
       return(E_POINTER);
    }
 
-   if (UnmapViewOfFile(pMappedViewStruct->BaseAddress) == FALSE) {
+   if (UnmapViewOfFile(pMappedViewStruct->BaseAddress) == false) {
       hResult = HRESULT_FROM_WIN32(GetLastError());
       return (hResult);
    }
 
-   if (CloseHandle(pMappedViewStruct->MapHandle) == FALSE) {
+   if (CloseHandle(pMappedViewStruct->MapHandle) == false) {
       hResult = HRESULT_FROM_WIN32(GetLastError());
       return (hResult);
    }
@@ -822,7 +822,7 @@ UtilMappedViewWriteBegin(
 HRESULT
 UtilSharedMemoryBegin(
    const char*          pMappingName,
-   INT64                size,
+   int64_t                size,
    PMAPPED_VIEW_STRUCT *pReturnStruct) {
 
    // NULL indicates failure - default to that.
@@ -918,18 +918,18 @@ HRESULT
 UtilSharedMemoryCopy(
    const char*          pMappingName,
    PMAPPED_VIEW_STRUCT *pReturnStruct,
-   BOOL                 bTest) {
+   int                 bTest) {
 
    // NULL indicates failure - default to that.
    *pReturnStruct = NULL;
    errno = 0;
-   BOOL bCanOnlyRead = FALSE;
+   bool bCanOnlyRead = false;
 
    LOGGING("Trying to open shared memory %s.\n", pMappingName);
    int     fd = shm_open(pMappingName, O_RDWR, 0666);
 
    if (fd <= 0) {
-      bCanOnlyRead = TRUE;
+      bCanOnlyRead = true;
       fd = shm_open(pMappingName, O_RDONLY, 0666);
    }
 
@@ -996,4 +996,4 @@ UtilSharedMemoryEnd(
    return 0;
 }
 
-#endif
\ No newline at end of file
+#endif
